        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 17 <strong>control</strong><br>0,3,6,9,12,13,16,23,24,27,32,33,35,36,41,45,49';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>44</strong> miembros: 13 <br>1,4,8,20,21,22,26,29,34,39,40,44,47';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>25</strong> miembros: 13 <br>2,11,14,17,18,25,28,30,31,37,38,42,50';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>4</strong> representante: <strong>46</strong> miembros: 5 <br>7,10,43,46,48';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260514 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>5</strong> representante: <strong>19</strong> miembros: 3 <br>5,15,19';}
}
